# Hkube

[Hkube](https://github.com/kube-HPC/hkube) - cloud-native open source framework to run distributed pipeline of algorithms

## TL;DR;

```console
$ helm repo add hkube https://hkube.org/helm
$ helm repo update
$ helm install hkube hkube/hkube  --version=0.1.2
```

## Introduction

This chart deploys  on a [Kubernetes](http://kubernetes.io) cluster using the [Helm](https://helm.sh) package manager.

## Prerequisites
Hkube requires a working installation of kubernetes.  
There are many options for local k8s installations. e.g  [Minikube](https://kubernetes.io/docs/tasks/tools/install-minikube/) or [microk8s](https://microk8s.io/).  

Hkube is installed using helm. Both helm 2 and the newer [helm 3](https://helm.sh/docs/intro/install/) should work.

> Make sure kubectl is configured to your cluster.  
> For collecting algorithm logs, and to create builds, Hkube requires that certain pods will run in privileged security permissions. Consult your kubernetes installation to see how to do that. "`--allow-privileged` flag must be set to true for both the API server and the kubelet (or set global.isPrivileged=false)"


- Kubernetes v1.14+
- Dynamic storage provisioning (optional)
- Ingress controller (optional)

## Installing the Chart

To install the chart with the release name `hkube`:

```console
$ helm repo add hkube http://hkube.io/helm/
$ helm install hkube hkube/hkube
```

The command deploys  on the Kubernetes cluster in the default configuration. The [configuration](#configuration) section lists the parameters that can be configured during installation.

> **Tip**: List all releases using `helm list`

## Uninstalling the Chart

To uninstall/delete the `hkube`:

```console
$ helm delete hkube 
```

The command removes all the Kubernetes components associated with the chart and deletes the release.

## Configuration

The following table lists the configurable parameters of the `hkube` chart and their default values.

|                       Parameter                       |                                                                                                                                                                                                                        Description                                                                                                                                                                                                                         |                                               Default                                               |
|-------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------|
| global.clusterName                                    | kubernetes cluster domain name                                                                                                                                                                                                                                                                                                                                                                                                                             | <code>cluster.local</code>                                                                          |
| global.registry                                       | private registry to use                                                                                                                                                                                                                                                                                                                                                                                                                                    | <code>""</code>                                                                                     |
| global.registry_namespace                             | private registry namespace for pulling images in builds                                                                                                                                                                                                                                                                                                                                                                                                    | <code>hkube</code>                                                                                  |
| global.registry_username                              | private registry username for pulling images                                                                                                                                                                                                                                                                                                                                                                                                               | <code>""</code>                                                                                     |
| global.registry_password                              | private registry password for pulling images                                                                                                                                                                                                                                                                                                                                                                                                               | <code>""</code>                                                                                     |
| global.registry_insecure                              | private registry insecure (http) for pulling base image in builds                                                                                                                                                                                                                                                                                                                                                                                          | <code>false</code>                                                                                  |
| global.registry_skip_tls_verify                       | private registry with self signed certificate for pulling base image in builds                                                                                                                                                                                                                                                                                                                                                                             | <code>false</code>                                                                                  |
| global.image_pull_secret.name                         | name of imagepullsecret. If global.registry_password is not empty, it will be created                                                                                                                                                                                                                                                                                                                                                                      | <code>hkube-imagepullsecret</code>                                                                  |
| global.image_pull_secret.use_existing                 | use an existing imagepullsecret (doesn't create the secret)                                                                                                                                                                                                                                                                                                                                                                                                | <code>false</code>                                                                                  |
| global.resources_enable                               | If false, will not set resource request and limits on hkube pods. If true will set the values for each pod                                                                                                                                                                                                                                                                                                                                                 | <code>false</code>                                                                                  |
| global.storage.encoding                               | encoding for storage. can be msgpack, bson, json                                                                                                                                                                                                                                                                                                                                                                                                           | <code>msgpack</code>                                                                                |
| global.storage.maxCacheSize                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>500</code>                                                                                    |
| global.storage.s3.access_key                          | s3 access and secret key. If using internal minio, must match minio.accessKey and secretKey                                                                                                                                                                                                                                                                                                                                                                | <code>hkubeminiokey</code>                                                                          |
| global.storage.s3.secret_key                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>hkubeminiosecret</code>                                                                       |
| global.storage.s3.url                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"http://hkube-minio:9000"</code>                                                              |
| global.k8senv                                         | kubernetes environment. Possible values are k8s, openshift                                                                                                                                                                                                                                                                                                                                                                                                 | <code>k8s</code>                                                                                    |
| global.namespaced                                     | use only namespace. Set to true in restricted environments such as openshift                                                                                                                                                                                                                                                                                                                                                                               | <code>false</code>                                                                                  |
| global.isPrivileged                                   | run worker pods as privileged containers. Makes log aggregation easier                                                                                                                                                                                                                                                                                                                                                                                     | <code>true</code>                                                                                   |
| global.ingress.hostname                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>""</code>                                                                                     |
| global.ingress.prefix                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>""</code>                                                                                     |
| global.ingress.use_regex                              | set to false if using nginx-ingress-controller prior to 0.21                                                                                                                                                                                                                                                                                                                                                                                               | <code>true</code>                                                                                   |
| global.ingress.requireTls                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>false</code>                                                                                  |
| global.ingress.maxBodySize                            |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>500m</code>                                                                                   |
| global.ingress.class                                  |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>nginx</code>                                                                                  |
| global.sidecars.fluent_bit.enable                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>false</code>                                                                                  |
| global.sidecars.fluent_bit.config.name                |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>fluent-bit-cm</code>                                                                          |
| global.sidecars.fluent_bit.config.create_cm           |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| global.sidecars.fluent_bit.config.log_file            |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"*.log"</code>                                                                                |
| global.sidecars.fluent_bit.config.mount_path          |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>/mnt/log</code>                                                                               |
| global.sidecars.fluent_bit.config.es.url              |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>""</code>                                                                                     |
| global.sidecars.fluent_bit.config.es.port             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"9200"</code>                                                                                 |
| global.sidecars.fluent_bit.config.es.tls              |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"Off"</code>                                                                                  |
| global.sidecars.fluent_bit.config.es.tls_verify       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"Off"</code>                                                                                  |
| global.sidecars.fluent_bit.config.es.logStashPrefix   |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"hkube-"</code>                                                                               |
| global.sidecars.fluent_bit.config.es.user             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>""</code>                                                                                     |
| global.sidecars.fluent_bit.config.es.password         |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>""</code>                                                                                     |
| global.sidecars.fluent_bit.resources.limits.cpu       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>100m</code>                                                                                   |
| global.sidecars.fluent_bit.resources.limits.memory    |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>200Mi</code>                                                                                  |
| env.kibana_url                                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"https://cicd.hkube.org/system/kibana/"</code>                                                |
| env.grafana_url                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"https://cicd.hkube.org/grafana"</code>                                                       |
| env.default_storage                                   | storage mode. can be s3 or fs. Set global.storage.fs or global.storage.s3 accordingly                                                                                                                                                                                                                                                                                                                                                                      | <code>s3</code>                                                                                     |
| env.node_env                                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>production</code>                                                                             |
| image.pullPolicy                                      | pull policy for images                                                                                                                                                                                                                                                                                                                                                                                                                                     | <code>IfNotPresent</code>                                                                           |
| etcd.enable                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| etcd.replicas                                         | set number of replicas. defualt 3                                                                                                                                                                                                                                                                                                                                                                                                                          | <code>3</code>                                                                                      |
| etcd.persistentVolume.enabled                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| etcd.persistentVolume.storageClass                    |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>""</code>                                                                                     |
| etcd.persistentVolume.storage                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>10Gi</code>                                                                                   |
| etcd.resources                                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>{}</code>                                                                                     |
| redis-ha.enable                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| redis-ha.replicas                                     | set number of replicas. defualt 3. If set to 1 also set min-slaves-to-write to 0                                                                                                                                                                                                                                                                                                                                                                           | <code>3</code>                                                                                      |
| redis-ha.redis.config.min-slaves-to-write             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>1</code>                                                                                      |
| redis-ha.redis.config.client-output-buffer-limit      |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"replica 1024mb 512mb 60"</code>                                                              |
| redis-ha.redis.resources                              |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>{}</code>                                                                                     |
| redis-ha.sentinel.resources                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>{}</code>                                                                                     |
| redis-ha.hardAntiAffinity                             | We usually recommend not to specify default resources and to leave this as a conscious choice for the user. This also increases chances charts run on environments with little resources, such as Minikube. If you do want to specify resources, uncomment the following lines, adjust them as necessary, and remove the curly braces after 'resources:'. limits: cpu: 300m memory: 512Mi requests: cpu: 100m memory: 256Mi set to true for multiple nodes | <code>false</code>                                                                                  |
| jaeger.enable                                         | enable jaeger and cassandra                                                                                                                                                                                                                                                                                                                                                                                                                                | <code>false</code>                                                                                  |
| jaeger.fullnameOverride                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>jaeger</code>                                                                                 |
| jaeger.nameOverride                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>jaeger</code>                                                                                 |
| jaeger.query.basePath                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>/jaeger</code>                                                                                |
| jaeger.query.ingress.enabled                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| jaeger.agent.deploymentKind                           | set the deployment kind of the jaeger-agent. options are daemonset and deployment                                                                                                                                                                                                                                                                                                                                                                          | <code>daemonset</code>                                                                              |
| jaeger.agent.deployment.replicas                      |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>1</code>                                                                                      |
| jaeger.agent.daemonset.useHostPort                    | set to false to allow running in non privileged environment (e.g. openshift)                                                                                                                                                                                                                                                                                                                                                                               | <code>true</code>                                                                                   |
| jaeger.cassandra.persistence.enabled                  |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| jaeger.cassandra.persistence.storageClass             | cassandra data Persistent Volume Storage Class If defined, storageClassName: <storageClass> If set to "-", storageClassName: "", which disables dynamic provisioning If undefined (the default) or set to null, no storageClassName spec is set, choosing the default provisioner.  (gp2 on AWS, standard on GKE, AWS & OpenStack)                                                                                                                         | <code>null</code>                                                                                   |
| jaeger.cassandra.config.cluster_size                  |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>1</code>                                                                                      |
| jaeger.cassandra.config.cluster_domain                |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>cluster.local</code>                                                                          |
| jaeger.external_agent_address                         | optional external jaeger agent address. leave blank for defaults                                                                                                                                                                                                                                                                                                                                                                                           | <code>""</code>                                                                                     |
| nginx-ingress.enable                                  | install nginx-ingress-controller with hkube                                                                                                                                                                                                                                                                                                                                                                                                                | <code>false</code>                                                                                  |
| mongodb.enable                                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| mongodb.persistence.storageClass                      |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>null</code>                                                                                   |
| mongodb.useStatefulSet                                |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| mongodb.auth.rootPassword                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>ehtyTJj4mR</code>                                                                             |
| mongodb.auth.user_name                                |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>root</code>                                                                                   |
| mongodb.auth.databaseName                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>hkube</code>                                                                                  |
| mongodb.podSecurityContext.enabled                    |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>false</code>                                                                                  |
| mongodb.containerSecurityContext.enabled              |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>false</code>                                                                                  |
| minio.enable                                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| minio.accessKey                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>hkubeminiokey</code>                                                                          |
| minio.secretKey                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>hkubeminiosecret</code>                                                                       |
| minio.persistence.enabled                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| minio.persistence.storageClass                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>""</code>                                                                                     |
| minio.resources                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>{}</code>                                                                                     |
| minio.secContext.overrideMinio                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>false</code>                                                                                  |
| minio.secContext.runAsUser                            |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>3000</code>                                                                                   |
| minio.secContext.runAsGroup                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>4000</code>                                                                                   |
| minio.secContext.fsGroup                              |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>5000</code>                                                                                   |
| keycloak.enable                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| keycloak.api_server.client_secretKey                  | override value if needed                                                                                                                                                                                                                                                                                                                                                                                                                                   | <code>r3gmlUZ2Bx3vL7iB79rNKMQjaYTqshVK</code>                                                       |
| keycloak.env.hostname_strict                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| keycloak.env.http_enabled                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| keycloak.env.hostname_url                             | replace with keycloak's domain and full url, for keycloak ingress to operate correctly.                                                                                                                                                                                                                                                                                                                                                                    | <code>https://env.hkube.org/hkube/keycloak</code>                                                   |
| keycloak.env.hostname_admin_url                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>https://env.hkube.org/hkube/keycloak</code>                                                   |
| gitea.enable                                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| gitea.persistence.storageClass                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>null</code>                                                                                   |
| gitea.service.http.port                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"3000"</code>                                                                                 |
| gitea.gitea.config.repository.ENABLE_PUSH_CREATE_USER |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| gitea.gitea.admin.username                            |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>hkube</code>                                                                                  |
| gitea.gitea.admin.password                            |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"123456"</code>                                                                               |
| gitea.gitea.admin.email                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"hkube@hkube.io"</code>                                                                       |
| gitea.postgresql.persistence.storageClass             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>null</code>                                                                                   |
| gitea.postgresql.securityContext.enabled              |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>false</code>                                                                                  |
| gitea.postgresql.containerSecurityContext.enabled     |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>false</code>                                                                                  |
| gitea.memcached.securityContext.enabled               |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>false</code>                                                                                  |
| metrics.serviceMonitorSelector.release                |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>metric</code>                                                                                 |
| metrics.grafanaDashboardLabel.grafana_dashboard       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"1"</code>                                                                                    |
| metrics.grafana_version                               | set to '7' when use Grafana version >= 7, default '6'                                                                                                                                                                                                                                                                                                                                                                                                      | <code>"7"</code>                                                                                    |
| metrics.grafana_data_source                           | set the name of the data source defined in grafana, where hkube metrics are collected ./dashboards/grafana_dashboards/*.json files                                                                                                                                                                                                                                                                                                                         | <code>Prometheus</code>                                                                             |
| metrics.pod_count_expr_v6                             | used to set 'expr' value in HKube_status.json, replaces the partial string "${podCountExpr}" for grafana_version == 6                                                                                                                                                                                                                                                                                                                                      | <code>"count(mixin_pod_workload{workload="</code>                                                   |
| metrics.pod_count_expr_v7                             | used to set 'expr' value in HKube_status.json, replaces the partial string "${podCountExpr}" for grafana_version == 7                                                                                                                                                                                                                                                                                                                                      | <code>"count(kube_pod_status_phase{phase='Running',pod="</code>                                     |
| systemversion                                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>v2.8.53</code>                                                                                |
| build_secret.docker_registry                          | docker registry for algorithm builds. defaults to docker.io                                                                                                                                                                                                                                                                                                                                                                                                | <code>""</code>                                                                                     |
| build_secret.docker_namespace                         | docker registry namespace for algorithm builds. defaults to username                                                                                                                                                                                                                                                                                                                                                                                       | <code>""</code>                                                                                     |
| build_secret.docker_username                          | docker registry username for algorithm builds.                                                                                                                                                                                                                                                                                                                                                                                                             | <code>""</code>                                                                                     |
| build_secret.docker_password                          | docker registry password for algorithm builds.                                                                                                                                                                                                                                                                                                                                                                                                             | <code>""</code>                                                                                     |
| build_secret.docker_registry_insecure                 | docker registry is insecure for algorithm builds.                                                                                                                                                                                                                                                                                                                                                                                                          | <code>false</code>                                                                                  |
| build_secret.docker_registry_skip_tls_verify          | docker registry has self signed certificate for algorithm builds.                                                                                                                                                                                                                                                                                                                                                                                          | <code>false</code>                                                                                  |
| build_secret.npm_registry                             | npm registry for algorithm builds. Defaults to npmjs.com                                                                                                                                                                                                                                                                                                                                                                                                   | <code>""</code>                                                                                     |
| build_secret.npm_token                                | npm registry token for algorithm builds. Mutually exclusive with npm_user and npm_password                                                                                                                                                                                                                                                                                                                                                                 | <code>""</code>                                                                                     |
| build_secret.npm_user                                 | npm registry user for algorithm builds. Mutually exclusive with npm_token                                                                                                                                                                                                                                                                                                                                                                                  | <code>""</code>                                                                                     |
| build_secret.npm_password                             | npm registry password for algorithm builds. Mutually exclusive with npm_token                                                                                                                                                                                                                                                                                                                                                                              | <code>""</code>                                                                                     |
| build_secret.pip_registry                             | pip registry for algorithm builds. Defaults to pypi.org                                                                                                                                                                                                                                                                                                                                                                                                    | <code>""</code>                                                                                     |
| build_secret.pip_token                                | pip registry token for algorithm builds. Defaults to pypi.org                                                                                                                                                                                                                                                                                                                                                                                              | <code>""</code>                                                                                     |
| build_secret.maven_registry                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>""</code>                                                                                     |
| build_secret.maven_token                              |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>""</code>                                                                                     |
| build_secret.maven_user                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>""</code>                                                                                     |
| nodeSelector                                          | node selector for hkube containers.                                                                                                                                                                                                                                                                                                                                                                                                                        | <code>{}</code>                                                                                     |
| site.env                                              |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>{}</code>                                                                                     |
| site.image.repository                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>hkube/site</code>                                                                             |
| site.image.tag                                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>v2.8.12</code>                                                                                |
| site.base_url                                         | base_url for site-related links, default is /hkube/site                                                                                                                                                                                                                                                                                                                                                                                                    | <code>"/hkube/site"</code>                                                                          |
| site.ingress.enabled                                  |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| site.ingress.path                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>hkube/site</code>                                                                             |
| site.service.port                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>8444</code>                                                                                   |
| site.service.type                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>ClusterIP</code>                                                                              |
| site.resources.limits.cpu                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>200m</code>                                                                                   |
| site.resources.limits.memory                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>512Mi</code>                                                                                  |
| site.resources.requests.cpu                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>100m</code>                                                                                   |
| site.resources.requests.memory                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>256Mi</code>                                                                                  |
| algorithm_operator.build_mode                         | build mode for automatic builds. set to openshift if running on openshift                                                                                                                                                                                                                                                                                                                                                                                  | <code>kaniko</code>                                                                                 |
| algorithm_operator.resources_enable                   | enable resource limits for algorithm operator                                                                                                                                                                                                                                                                                                                                                                                                              | <code>false</code>                                                                                  |
| algorithm_operator.resources                          | Compute resources required for algorithm-operator                                                                                                                                                                                                                                                                                                                                                                                                          | <code>{"limits":{"cpu":"300m","memory":"1024Mi"},"requests":{"cpu":"100m","memory":"512Mi"}}</code> |
| api_gateway.ingress.path                              |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>/hkube/api-server</code>                                                                      |
| api_gateway.ingress.enabled                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>true</code>                                                                                   |
| pipeline_driver.env.metric_port                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"3001"</code>                                                                                 |
| pipeline_driver.env.storageResultsThreshold           |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>"100Ki"</code>                                                                                |
| pipeline_driver.env.status_delay_ms                   | time pipeline driver tries to wait for the status of a pod to change when stopping                                                                                                                                                                                                                                                                                                                                                                         | <code>"25000"</code>                                                                                |
| pipeline_driver.image.repository                      |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>hkube/pipeline-driver</code>                                                                  |
| pipeline_driver.image.tag                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>v2.8.7</code>                                                                                 |
| pipeline_driver.service.type                          |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>ClusterIP</code>                                                                              |
| task_executor.env.worker_socket_max_payload_bytes     |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>1000000000</code>                                                                             |
| task_executor.env.worker_algorithm_start_timeout_ms   |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>300000</code>                                                                                 |
| task_executor.env.created_jobs_ttl                    | interval in MS, in which we verify if a job was deployed                                                                                                                                                                                                                                                                                                                                                                                                   | <code>15000</code>                                                                                  |
| task_executor.env.worker_memory                       | worker container memory request in MB. Only set if resources_enable=true                                                                                                                                                                                                                                                                                                                                                                                   | <code>512</code>                                                                                    |
| task_executor.env.worker_cpu                          | worker container cpu request. Only set if resources_enable=true                                                                                                                                                                                                                                                                                                                                                                                            | <code>0.1</code>                                                                                    |
| task_executor.env.resources_enable                    | if true, sets resource requests on worker container                                                                                                                                                                                                                                                                                                                                                                                                        | <code>false</code>                                                                                  |
| task_executor.env.interval                            | task executor internal processing interval in MS                                                                                                                                                                                                                                                                                                                                                                                                           | <code>"1000"</code>                                                                                 |
| task_executor.env.default_quota_cpu                   | set to the number of CPUs in the cluster (or quota) when running on openshift                                                                                                                                                                                                                                                                                                                                                                              | <code>30</code>                                                                                     |
| task_executor.env.default_quota_mem                   | set to the total amount of memory in the cluster (or quota) when running on openshift                                                                                                                                                                                                                                                                                                                                                                      | <code>20Gi</code>                                                                                   |
| task_executor.env.default_quota_gpu                   | set to the total number of GPUs in the cluster (or quota) when running on openshift                                                                                                                                                                                                                                                                                                                                                                        | <code>0</code>                                                                                      |
| task_executor.env.has_node_list                       | if running on openshift on labeled nodes, set to true and create a config-map named `hkube-nodes` with key `hkube-nodes` and value of the output of `kubectl get nodes -o json`                                                                                                                                                                                                                                                                            | <code>false</code>                                                                                  |
| task_executor.env.use_resource_limits                 | set to true to set algorithm resource limit to equal resource request                                                                                                                                                                                                                                                                                                                                                                                      | <code>false</code>                                                                                  |
| task_executor.env.pods_output_log_folder              | path where kubernetes stores the pods output logs.                                                                                                                                                                                                                                                                                                                                                                                                         | <code>'/var/lib/docker/containers'</code>                                                           |
| task_executor.env.cpu_ratio_pressure                  | defines the amount of reserved cpu , should be between 0 and 1, reserved amount is (1-value)                                                                                                                                                                                                                                                                                                                                                               | <code>0.9</code>                                                                                    |
| task_executor.env.memory_ratio_pressure               | defines the amount of reserved memory , should be between 0 and 1, reserved amount is (1-value)                                                                                                                                                                                                                                                                                                                                                            | <code>0.8</code>                                                                                    |
| task_executor.resources_enable                        |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>false</code>                                                                                  |
| task_executor.resources                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>{"limits":{"cpu":"300m","memory":"1024Mi"},"requests":{"cpu":"100m","memory":"512Mi"}}</code> |
| fullSystemVersion                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                            | <code>v2.8.53-1738222685274</code>                                                                  |


Specify each parameter using the `--set key=value[,key=value]` argument to `helm install`. For example:

```console
$ helm install hkube hkube/hkube  --version=0.1.2 --set global.clusterName=cluster.local
```

Alternatively, a YAML file that specifies the values for the parameters can be provided while
installing the chart. For example:

```console
$ helm install hkube hkube/hkube  --version=0.1.2 --values values.yaml
```